@@ -72,7 +72,7 @@ r_process_options_default <- function() {
     error = getOption("callr.error", "error"),
     cmdargs = c("--slave", "--no-save", "--no-restore"),
     system_profile = FALSE,
-    user_profile = FALSE,
+    user_profile = "project",
     env = character(),
     supervise = FALSE,
     load_hook = default_load_hook(),
@@ -90,7 +90,7 @@ rcmd_process_options_default <- function() {
     poll_connection = TRUE,
     repos = default_repos(),
     system_profile = FALSE,
-    user_profile = FALSE,
+    user_profile = "project",
     env = rcmd_safe_env(),
     wd = ".",
     supervise = FALSE,
@@ -108,7 +108,7 @@ rscript_process_options_default <- function() {
     poll_connection = TRUE,
     repos = default_repos(),
     system_profile = FALSE,
-    user_profile = FALSE,
+    user_profile = "project",
     env = rcmd_safe_env(),
     wd = ".",
     color = FALSE,
