@@ -2,7 +2,7 @@
 setup_script_files <- function(options) {
   within(options, {
     func_file   <- save_function_to_temp(options)
-    result_file <- tempfile()
+    result_file <- tempfile("callr-res-")
     script_file <- make_vanilla_script_file(
       func_file, result_file, options$error)
     tmp_files <- c(tmp_files, func_file, script_file, result_file)
@@ -10,7 +10,7 @@ setup_script_files <- function(options) {
 }
 
 save_function_to_temp <- function(options) {
-  tmp <- tempfile()
+  tmp <- tempfile("callr-fun-")
   environment(options$func) <- .GlobalEnv
   saveRDS(list(options$func, options$args), file = tmp)
   tmp
@@ -33,12 +33,22 @@ setup_context <- function(options) {
     envs <- make_environ(profiles, libpath)
     tmp_files <- c(tmp_files, envs)
 
+    ## environment variables
+
+    ## First, save these, so we can restore them exactly in the subprocess,
+    ## and sub-subprocesses are not affected by our workarounds
+    save_env <- c("R_ENVIRON", "R_ENVIRON_USER", "R_PROFILE",
+                  "R_PROFILE_USER", "R_LIBS", "R_LIBS_USER", "R_LIBS_SITE")
+    save_set <- save_env %in% names(Sys.getenv())
+    save_nms <- paste0("CALLR_", save_env, "_BAK")
+    env[save_nms[save_set]] <- Sys.getenv(save_env[save_set])
+    env <- env[setdiff(names(env), save_nms[!save_set])]
+
     if (is.na(env["R_ENVIRON"])) env["R_ENVIRON"] <- envs[[1]]
     if (is.na(env["R_ENVIRON_USER"])) env["R_ENVIRON_USER"] <- envs[[2]]
     if (is.na(env["R_PROFILE"])) env["R_PROFILE"] <- profiles[[1]]
     if (is.na(env["R_PROFILE_USER"])) env["R_PROFILE_USER"] <- profiles[[2]]
 
-    ## environment variables
     if (is.na(env["R_LIBS"])) env["R_LIBS"] <- make_path(libpath)
     if (is.na(env["R_LIBS_USER"])) env["R_LIBS_USER"] <- make_path(libpath)
     if (is.na(env["R_LIBS_SITE"])) env["R_LIBS_SITE"] <- make_path(.Library.site)
@@ -47,8 +57,8 @@ setup_context <- function(options) {
 
 make_profiles <- function(system, user, repos, libpath, load_hook) {
 
-  profile_system <- tempfile()
-  profile_user <- tempfile()
+  profile_system <- tempfile("callr-spr-")
+  profile_user <- tempfile("callr-upr-")
 
   ## Create file2
   cat("", file = profile_system)
@@ -62,13 +72,25 @@ make_profiles <- function(system, user, repos, libpath, load_hook) {
     if (file.exists(sys)) file.append(profile_system, sys)
   }
 
-  if (user) {
+  if (identical(user, "project")) {
+    local <- ".Rprofile"
+    if (file.exists(local)) user <- local else user <- NA_character_
+  } else if (user) {
     user <- Sys.getenv("R_PROFILE_USER", NA_character_)
     local <- ".Rprofile"
     home  <- path.expand("~/.Rprofile")
     if (is.na(user) && file.exists(local)) user <- local
     if (is.na(user) && file.exists(home)) user <- home
-    if (!is.na(user) && file.exists(user)) file.append(profile_user, user)
+  } else {
+    user <- NA_character_
+  }
+
+  if (!is.na(user) && file.exists(user)) {
+    xpr <- substitute(
+      if (file.exists(user)) source(user, local = TRUE),
+      list(user = user)
+    )
+    cat(deparse(xpr), file = profile_user, append = TRUE, sep = "\n")
   }
 
   ## Override repos, as requested
@@ -96,8 +118,8 @@ make_profiles <- function(system, user, repos, libpath, load_hook) {
 
 make_environ <- function(profiles, libpath) {
 
-  env_sys <- tempfile()
-  env_user <- tempfile()
+  env_sys <- tempfile("callr-sev-")
+  env_user <- tempfile("callr-uev-")
 
   for (ef in c(env_sys, env_user)) {
     cat("CALLR_CHILD_R_LIBS=\"${R_LIBS}\"\n",
@@ -157,7 +179,7 @@ setup_callbacks <- function(options) {
     force(stream)
 
     ## In case there is no output, we create an empty file here
-    if (!is.null(stream)) cat("", file = stream)
+    if (!is.null(stream) && stream != "2>&1") cat("", file = stream)
 
     if (!is.null(cb)) {
       function(x, proc) {
